@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2020, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -85,7 +85,7 @@ public:
     virtual const QFont *font(Font type = SystemFont) const override;
     virtual QVariant themeHint(ThemeHint hint) const override;
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
-    virtual QIcon fileIcon(const QFileInfo &fileInfo, QPlatformTheme::IconOptions iconOptions = 0) const override;
+    virtual QIcon fileIcon(const QFileInfo &fileInfo, QPlatformTheme::IconOptions iconOptions = {}) const override;
 #endif
     //virtual QPixmap standardPixmap(StandardPixmap sp, const QSizeF &size) const;
     //virtual QPixmap fileIconPixmap(const QFileInfo &fileInfo, const QSizeF &size,
@@ -110,7 +110,7 @@ private:
     QString loadStyleSheets(const QStringList &paths);
     QPalette loadColorScheme(const QString &filePath);
     QString m_style, m_iconTheme, m_userStyleSheet, m_prevStyleSheet;
-    QPalette *m_customPalette = nullptr;
+    QPalette *m_palette = nullptr;
     QFont m_generalFont, m_fixedFont;
     int m_doubleClickInterval;
     int m_cursorFlashTime;
