@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2020, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -29,14 +29,18 @@
 #include <QApplication>
 #include <QLibraryInfo>
 #include <QLocale>
-#include "qt5ct.h"
+#include <QtGlobal>
 #include <QTranslator>
 #include <QtDebug>
+#include "qt5ct.h"
 #include "mainwindow.h"
 
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0))
+    QGuiApplication::setDesktopFileName("qt5ct.desktop");
+#endif
     QTranslator translator;
     QString locale = Qt5CT::systemLanguageID();
     translator.load(QString(":/qt5ct_") + locale);
