@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2020, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -184,7 +184,7 @@ void QSSPage::findStyleSheets(const QString &path)
     dir.setFilter(QDir::Files);
     dir.setNameFilters(QStringList() << "*.qss");
 
-    foreach (QFileInfo info, dir.entryInfoList())
+    for(const QFileInfo &info : dir.entryInfoList())
     {
         QListWidgetItem *item = new QListWidgetItem(info.fileName(),  m_ui->qssListWidget);
         item->setToolTip(info.filePath());
@@ -195,7 +195,7 @@ void QSSPage::findStyleSheets(const QString &path)
 
 void QSSPage::findStyleSheets(const QStringList &paths)
 {
-    foreach (QString p, paths)
+    for(const QString &p : paths)
         findStyleSheets(p);
 }
 
