@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2020, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -65,22 +65,22 @@ QString Qt5CT::configFile()
 
 QStringList Qt5CT::iconPaths()
 {
-    QStringList paths;
+    QStringList paths, out;
     paths << QDir::homePath() + QLatin1String("/.icons");
 
-    foreach (QString p, QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation))
+    for(const QString &p : QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation))
     {
         paths << (p + QLatin1String("/icons"));
     }
     paths.removeDuplicates();
 
     //remove invalid
-    foreach (QString p, paths)
+    for(const QString &p : paths)
     {
-        if(!QDir(p).exists())
-            paths.removeAll(p);
+        if(QDir(p).exists())
+            out << p;
     }
-    return paths;
+    return out;
 }
 
 QString Qt5CT::userStyleSheetPath()
@@ -91,7 +91,7 @@ QString Qt5CT::userStyleSheetPath()
 QStringList Qt5CT::sharedStyleSheetPaths()
 {
     QStringList paths;
-    foreach (QString p, QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation))
+    for(const QString &p : QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation))
     {
         paths << (p + QLatin1String("/qt5ct/qss"));
     }
@@ -108,7 +108,7 @@ QString Qt5CT::userColorSchemePath()
 QStringList Qt5CT::sharedColorSchemePaths()
 {
     QStringList paths;
-    foreach (QString p, QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation))
+    for(const QString &p : QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation))
     {
         paths << (p + QLatin1String("/qt5ct/colors"));
     }
